%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%================== AHRP Berichte Class===================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ahrp}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%================== based on "article" class =============================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass[twocolumn,twoside,11pt]{article}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Check if fixltx2e is required:
\begingroup\expandafter\expandafter\expandafter\endgroup
\expandafter\ifx\csname IncludeInRelease\endcsname\relax
 \RequirePackage{fixltx2e}
\fi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ========================== Packages ====================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{emptypage}
\RequirePackage{babel}
\RequirePackage[T1]{fontenc}
%  %  %  TikZ & pgfplots  %  %  %
\RequirePackage{tikz} % TikZ ist kein Zeichenprogramm!
\RequirePackage{pgfplots}
\usetikzlibrary{shapes.misc,calc}
\pgfplotsset{compat=newest}
%  %  %  %  %  %  %  %  %  %  %  %
%\RequirePackage{extsizes}
%  %  %  Bibliography  %  %  %
\RequirePackage[super,sort&compress,comma]{natbib}
%  %  %  %  %  %  %  %  %  %  %
%  %  %  Page Setup  %  %  %
\RequirePackage{geometry}
\geometry{a4paper}% paper format
\geometry{left=2.2cm, right=2.2cm, top=1.9cm, bottom=2.0cm}% margins
%  %  %  %  %  %  %  %  %  %
\RequirePackage{balance}
\RequirePackage{booktabs}
\RequirePackage{times,mathptmx}
%\RequirePackage{sectsty} Last update: 25.2.2002
\RequirePackage{graphicx}
\RequirePackage{lastpage}
%  %  %  Captions  %  %  %
\RequirePackage[
			format=plain,
			justification=justified,
			singlelinecheck=false,
			%font={stretch=1.125,small,sf},
			font={small,sf},
			labelfont=bf,
			labelsep=space
			]{caption}
%  %  %  %  %  %  %  %  % 			
\RequirePackage{float}
\RequirePackage{fancyhdr}
\RequirePackage{fnpos}
\RequirePackage{array}
%\RequirePackage{times}
\RequirePackage{setspace}
\RequirePackage[compact]{titlesec}
\RequirePackage{xstring}
%  %  %  Math, Units, Chem. Eq.  %  %  %
\RequirePackage{amsmath,amsfonts,amssymb}
\RequirePackage[binary-units = true]{siunitx} % SI Units
\sisetup{
					exponent-product = \cdot,
					output-product = \cdot,
					tight-spacing = true,
					separate-uncertainty = true
					}
\RequirePackage[version=3]{mhchem}
%  %  %  %  %  %  %  %  %  %  %  %  %  %
\RequirePackage[gen]{eurosym}
\RequirePackage{enumitem}
\RequirePackage{epstopdf} % This line makes .eps figures into .pdf - please comment out if not required.
\RequirePackage{pdfpages}
\RequirePackage{textcase} % Provides MakeTextUppercase & MakeTextlowercase
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%==========================Line breaking==================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{textcomp}
\RequirePackage[
activate={true,nocompatibility},% activate protrusion and expansion
final=true,% enable microtype; "false" to disable
%step=1,%
tracking=true,%
kerning=true,%
spacing=true,%
%factor=1100,% add 10% to the protrusion amount (default is 1000)
%stretch=10,% reduce stretchability (default is 20)
%shrink=10% reduce shrinkability (default is 20)
]{microtype}% Text Companion Fonts
\microtypecontext{spacing=nonfrench}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% No orphans:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\clubpenalty = 10000
\widowpenalty = 10000
\displaywidowpenalty = 10000
\hyphenpenalty=1000
\linepenalty=1000
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ================== Always load hyperref last ! =========================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[
 plainpages=false,
 bookmarks=true,
 pdfstartview={FitH},
 colorlinks=true,
 citecolor=blue,
 linkcolor=JGURed,
 urlcolor=JGURed,
 pdfproducer={AHRP},
 pdfcreator={A. Henkel},
 hyperfootnotes=false % Makes the footnote marks into hyperlinks
 ]{hyperref}

% break also on hyphens inside the \url command
\def\UrlBreaks{\do\.\do\@\do\\\do\/\do\!\do\_\do\|\do\;\do\>\do\]%
  \do\)\do\,\do\?\do\'\do+\do\=\do\#\do-} % \do- is new!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ====================== End Packages ====================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ========================== Colors ======================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\definecolor{TUKLblue}{RGB}{0,95,140}
\definecolor{JGURed}{RGB}{193,0,42}
\definecolor{JUKL}{RGB}{96,47,93}
\definecolor{CoolGrey10}{RGB}{99,99,99}
\definecolor{CoolGrey7}{RGB}{172,172,172}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ======================== End Colors ====================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ======================= Bibliography ===================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{ourbibliography}[1]
{\begingroup\renewcommand{\section}[2]{}\begin{thebibliography}{#1}}
  {\end{thebibliography}\endgroup}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ===================== End Bibliography =================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ==================== Page Setup/Layout =================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % %    Please do not change any commands within this section !!!   % % %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\makeFNbottom
\makeatletter
\renewcommand\LARGE{\@setfontsize\LARGE{15pt}{17}}
\renewcommand\Large{\@setfontsize\Large{12pt}{14}}
\renewcommand\large{\@setfontsize\large{10pt}{12}}
\renewcommand\footnotesize{\@setfontsize\footnotesize{7pt}{10}}
\newcommand\footnoteref[1]{\protected@xdef\@thefnmark{\ref{#1}}\@footnotemark}
\makeatother

\renewcommand{\thefootnote}{\alph{footnote}}
\setlength{\footnotesep}{0.25cm}
\setlength{\skip\footins}{0.6cm}

%\renewcommand\footnoterule{\vspace*{1pt}%
% \color{CoolGrey7}\hrule width 3.5in height 0.4pt \color{black}\vspace*{5pt}}

\renewcommand\footnoterule{
\kern -3pt
 {\color{CoolGrey7}\hrule width \columnwidth}
\kern 2.6pt
}

\setcounter{secnumdepth}{5}

\makeatletter
\renewcommand\@biblabel[1]{#1}
\renewcommand\@makefntext[1]%
{\noindent\makebox[0pt][r]{\@thefnmark\,}#1}
\makeatother
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   %   %   Change captions name, \ref, \autoref   %   %   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\addto\captionsenglish{\renewcommand{\figurename}{Fig.}}
\addto\captionsngerman{\renewcommand{\figurename}{Abb.}}
\addto\captionsenglish{\renewcommand{\tablename}{Tab.}}
\addto\captionsngerman{\renewcommand{\tablename}{Tab.}}
%  %  %  Change autoref figure:  %  %  %
\addto\extrasngerman{%
  \renewcommand{\figureautorefname}{\figurename}%
}
\addto\extrasenglish{%
  \renewcommand{\figureautorefname}{\figurename}%
}
%  %  %  Change autoref table:  %  %  %
\addto\extrasngerman{%
  \renewcommand{\tableautorefname}{\tablename}%
}
\addto\extrasenglish{%
  \renewcommand{\tableautorefname}{\tablename}%
}
%  %  %  Change autoref equation:  %  %  %
\addto\extrasngerman{%
  \renewcommand{\equationautorefname}{Gl.}%
}
\addto\extrasenglish{%
  \renewcommand{\equationautorefname}{Eg.}%
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%\setlength{\itemsep}{0.5em}
\let\olditemize=\itemize \let\endolditemize=\enditemize \renewenvironment{itemize}{\olditemize \itemsep0.1em}{\endolditemize}
\setstretch{1.125} %In particular, please do not alter this line.
%\setlength{\jot}{10pt}
\titlespacing*{\section}{0pt}{4pt}{4pt}
\titlespacing*{\subsection}{0pt}{15pt}{1pt}
\renewcommand\thesection{}
\titleformat{name=\section}
{\sffamily\Large\bfseries}{\thesection}{0em}{\hspace{0em}}{}
\renewcommand\thesubsection{}
\titleformat{name=\subsection}
{\sffamily\large\bfseries}{\thesubsection}{1em}{\hspace{-1em}}{}
\renewcommand\thesubsubsection{}
\titleformat{name=\subsubsection}
{\sffamily\large\bfseries}{\thesubsubsection}{2em}{\hspace{-1em}}{}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ================== End Page Setup/Layout ===============================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ==================== Header/Footer Setup ===============================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\pagestyle{fancy}
\renewcommand{\headrule}{{\color{JUKL}%
   \hrule width \headwidth height \headrulewidth \vskip-\headrulewidth}}
	
\fancyhf{} % clears all header and footer fields

\fancyfoot{}
%\fancyfoot[RO]{\footnotesize{\sffamily{1--\pageref{LastPage} ~\textbar  \hspace{2pt}\thepage}}}
%\fancyfoot[LE]{\footnotesize{\sffamily{\thepage~\textbar\hspace{3.45cm} 1--\pageref{LastPage}}}}
\fancyfoot[RO,LE]{\footnotesize{\sffamily{\thepage~\textbar\hspace{0.25em} 1--\pageref{LastPage}}}}
\renewcommand{\headrulewidth}{2pt}
\renewcommand{\footrulewidth}{0pt}
\setlength{\arrayrulewidth}{1pt}
\setlength{\columnsep}{9mm}
\setlength\bibsep{1pt}
\setlength{\headheight}{14pt}


\fancyheadoffset[RO,LE]{2.5cm}
\fancyhead[LO]{\printcurrentsideheader}

\newcommand\setsideheader[2][CoolGrey10]{ %
 \gdef\currentColor{#1}
 \gdef\currentsideheader{#2}
}

\newcommand{\printcurrentsideheader}{
 \begin{tikzpicture}[overlay,remember picture]
  \node[fill=\currentColor,inner sep=3pt,rectangle,text width=1.4cm,
   text height=7cm,align=center,anchor=north east]
  at ($ (current page.north east) + (-0cm,-1.1cm) $)
  {\rotatebox{90}{\parbox[c][1.4cm][c]{7cm}{%
     \center\textcolor{white}{\expandafter\sffamily\bfseries\textsc{\LARGE\MakeTextUppercase{\currentsideheader}}}}}};
 \end{tikzpicture}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ================== End Header/Footer Setup =============================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ====================== Figure Setup ====================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % %   please do not change any commands within this section !!!   % % %
\makeatletter
\newlength{\figrulesep}
\setlength{\figrulesep}{0.5\textfloatsep}

\newcommand{\topfigrule}{\vspace*{-1pt}%
 \noindent{\color{JUKL}\rule[-\figrulesep]{\columnwidth}{1pt}} }

\newcommand{\botfigrule}{\vspace*{-2pt}%
 \noindent{\color{JUKL}\rule[\figrulesep]{\columnwidth}{1pt}} }

\newcommand{\dblfigrule}{\vspace*{-1pt}%
 \noindent{\color{JUKL}\rule[-\figrulesep]{\textwidth}{1pt}} }
\makeatother
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ==================== End Figure Setup ==================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ======================= Title Setup ====================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\reporttitle}[6]{%
 \twocolumn[
  \begin{@twocolumnfalse}
   \sffamily
   \noindent\MakeTextUppercase{\LARGE{\textbf{#1}}} %\\% Report title
   \vspace{3mm} \\ % \vspace{1mm}
   \noindent\large{#3, #4} \\
   \noindent\large{#2}\\
   \noindent\large{Hochleistungsrechner:\hskip 0.25em\relax}\MakeTextUppercase{\textbf{#5}}\large{, Nutzer: #6}

  \end{@twocolumnfalse} \vspace{1cm}
  \hypersetup{
	 pdfauthor={#2},
   pdfsubject={#1}}
 ]
 %\label{sec:#1}
 \IfBeginWith{#1}{JGU}{\setsideheader[JGURed]{#1}}{\IfBeginWith{#1}{TUKL}{\setsideheader[TUKLblue]{#1}}{\setsideheader{#1}}}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ==================== End Title Setup ===================================
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
